@@ -113,7 +113,8 @@ dPIG<-function(x, mu = 1, sigma = 1 , log = FALSE)
           if (any(mu <= 0) )  stop(paste("mu must be greater than 0 ", "\n", "")) 
           if (any(sigma <= 0) )  stop(paste("sigma must be greater than 0 ", "\n", "")) 
           if (any(x < 0) )  stop(paste("x must be >=0", "\n", ""))  
-          ly <- length(x)                                                                    
+          ly <- max(length(x),length(mu), length(sigma)) 
+           x <- rep(x, length = ly)      
       nsigma <- rep(sigma, length = ly)
          nmu <- rep(mu, length = ly)
       sumlty <- as.double(.C("tofyPIG2", as.double(x), as.double(nmu), as.double(nsigma),
